# PDDL Plus Parser
 A generic parser for PDDL+ and more!

## Requirements

## Features


## Changelog:
* version 0.0.1 - Initial release. Support for discrete PDDL domain and problem parsing.
* version 1.0.0 - Major extension to support PDDL 2.1 in terms of numeric actions.
* version 1.1.0 - Added support for Metric-FF solutions parsing.
* version 1.2.0 - Added support for ENHSP solution parsing.
* version 1.3.0 - Added problem generators for some domains used in the experiments. 
* version 1.4.0 - Added negative preconditions for actions.
* version 2.0.0 - Added support for multi-agent PDDL domains and problems.
* version 2.1.0 - Added support for more complex type of multi-agent trajectories to support non-trivial interactions. 
* version 2.2.0 - Added support for domains with disjunctive numeric preconditions.

